@@ -1,7 +1,7 @@
 #ifndef MY_AES_INCLUDED
 #define MY_AES_INCLUDED
 
-/* Copyright (c) 2000, 2021, Oracle and/or its affiliates.
+/* Copyright (c) 2000, 2022, Oracle and/or its affiliates.
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2.0,
@@ -27,6 +27,12 @@
 /* Header file for my_aes.c */
 /* Wrapper to give simple interface for MySQL to AES standard encryption */
 
+#include <string>
+#include <vector>
+
+using std::string;
+using std::vector;
+
 C_MODE_START
 
 /** AES IV size is 16 bytes for all supported ciphers except ECB */
@@ -68,12 +74,6 @@ enum my_aes_opmode
 /** String representations of the supported AES modes. Keep in sync with my_aes_opmode */
 extern const char *my_aes_opmode_names[];
 
-#ifdef __cplusplus
-  #define CPP_DEFAULT_PARAM(v) = v
-#else
-  #define CPP_DEFAULT_PARAM(v)
-#endif
-
 /**
   Encrypt a buffer using AES
 
@@ -85,6 +85,7 @@ extern const char *my_aes_opmode_names[];
   @param mode           [in]  encryption mode
   @param iv             [in]  16 bytes initialization vector if needed. Otherwise NULL
   @param padding        [in]  if padding needed.
+  @param kdf_options    [in]  KDF options
   @return              size of encrypted data, or negative in case of error
 */
 
@@ -92,7 +93,8 @@ int my_aes_encrypt(const unsigned char *source, uint32 source_length,
                    unsigned char *dest,
                    const unsigned char *key, uint32 key_length,
                    enum my_aes_opmode mode, const unsigned char *iv,
-                   my_bool padding CPP_DEFAULT_PARAM(TRUE));
+                   bool padding = true,
+                   vector<string> *kdf_options = NULL);
 
 /**
   Decrypt an AES encrypted buffer
@@ -105,6 +107,7 @@ int my_aes_encrypt(const unsigned char *source, uint32 source_length,
   @param mode           encryption mode
   @param iv             16 bytes initialization vector if needed. Otherwise NULL
   @param padding        if padding needed.
+  @param kdf_options    [in]  KDF options
   @return size of original data.
 */
 
@@ -113,7 +116,8 @@ int my_aes_decrypt(const unsigned char *source, uint32 source_length,
                    unsigned char *dest,
                    const unsigned char *key, uint32 key_length,
                    enum my_aes_opmode mode, const unsigned char *iv,
-                   my_bool padding CPP_DEFAULT_PARAM(TRUE));
+                   bool padding = true,
+                   vector<string> *kdf_options = NULL);
 
 /**
   Calculate the size of a buffer large enough for encrypted data
