@@ -1,15 +1,21 @@
-/* Copyright (c) 2002, 2004-2007 MySQL AB
-   Use is subject to license terms
+/* Copyright (c) 2002, 2022, Oracle and/or its affiliates.
    
    This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; version 2 of the License.
-   
+   it under the terms of the GNU General Public License, version 2.0,
+   as published by the Free Software Foundation.
+
+   This program is also distributed with certain software (including
+   but not limited to OpenSSL) that is licensed under separate terms,
+   as designated in a particular file or component or in included license
+   documentation.  The authors of MySQL hereby grant you an additional
+   permission to link the program and your derivative works with the
+   separately licensed software that they have included with MySQL.
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-   
+   GNU General Public License, version 2.0, for more details.
+
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA */
@@ -21,8 +27,6 @@
 #define SPTYPE HA_KEYTYPE_DOUBLE
 #define SPLEN  8
 
-#ifdef HAVE_SPATIAL
-
 enum wkbType
 {
   wkbPoint = 1,
@@ -43,5 +47,4 @@ enum wkbByteOrder
 uint sp_make_key(MI_INFO *info, uint keynr, uchar *key,
                  const uchar *record, my_off_t filepos);
 
-#endif /*HAVE_SPATIAL*/
 #endif /* _SP_DEFS_H */
